Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
aipyapp/__init__.py | 12 | 3 | 0 | 75%
aipyapp/__main__.py | 133 | 133 | 0 | 0%
aipyapp/__version__.py | 9 | 0 | 4 | 100%
aipyapp/aipy/__init__.py | 4 | 0 | 0 | 100%
aipyapp/aipy/agent_taskmgr.py | 118 | 118 | 0 | 0%
aipyapp/aipy/blocks.py | 206 | 167 | 0 | 19%
aipyapp/aipy/cache.py | 148 | 93 | 0 | 37%
aipyapp/aipy/config.py | 212 | 169 | 0 | 20%
aipyapp/aipy/context_manager.py | 317 | 243 | 0 | 23%
aipyapp/aipy/diagnose.py | 124 | 97 | 0 | 22%
aipyapp/aipy/event_recorder.py | 91 | 65 | 0 | 29%
aipyapp/aipy/event_serializer.py | 67 | 49 | 0 | 27%
aipyapp/aipy/functions.py | 72 | 53 | 0 | 26%
aipyapp/aipy/libmcp.py | 213 | 170 | 0 | 20%
aipyapp/aipy/llm.py | 177 | 135 | 0 | 24%
aipyapp/aipy/mcp_tool.py | 217 | 190 | 0 | 12%
aipyapp/aipy/multimodal.py | 116 | 88 | 0 | 24%
aipyapp/aipy/plugins.py | 96 | 76 | 0 | 21%
aipyapp/aipy/prompts.py | 78 | 53 | 0 | 32%
aipyapp/aipy/role.py | 127 | 94 | 0 | 26%
aipyapp/aipy/runtime.py | 98 | 70 | 0 | 29%
aipyapp/aipy/step_manager.py | 62 | 37 | 0 | 40%
aipyapp/aipy/task.py | 371 | 310 | 0 | 16%
aipyapp/aipy/task_state.py | 124 | 97 | 2 | 22%
aipyapp/aipy/taskmgr.py | 119 | 75 | 0 | 37%
aipyapp/aipy/trustoken.py | 104 | 87 | 0 | 16%
aipyapp/aipy/utils.py | 44 | 34 | 0 | 23%
aipyapp/aipy/wizard.py | 64 | 64 | 0 | 0%
aipyapp/cli/__init__.py | 0 | 0 | 0 | 100%
aipyapp/cli/cli_agent.py | 150 | 150 | 0 | 0%
aipyapp/cli/cli_ipython.py | 83 | 83 | 0 | 0%
aipyapp/cli/cli_python.py | 52 | 52 | 0 | 0%
aipyapp/cli/cli_task.py | 153 | 153 | 0 | 0%
aipyapp/cli/command/__init__.py | 3 | 3 | 0 | 0%
aipyapp/cli/command/base.py | 30 | 30 | 0 | 0%
aipyapp/cli/command/base_parser.py | 89 | 89 | 0 | 0%
aipyapp/cli/command/cmd_block.py | 47 | 47 | 0 | 0%
aipyapp/cli/command/cmd_context.py | 89 | 89 | 0 | 0%
aipyapp/cli/command/cmd_custom.py | 85 | 85 | 0 | 0%
aipyapp/cli/command/cmd_display.py | 29 | 29 | 0 | 0%
aipyapp/cli/command/cmd_help.py | 29 | 29 | 0 | 0%
aipyapp/cli/command/cmd_info.py | 14 | 14 | 0 | 0%
aipyapp/cli/command/cmd_llm.py | 30 | 30 | 0 | 0%
aipyapp/cli/command/cmd_mcp.py | 55 | 55 | 0 | 0%
aipyapp/cli/command/cmd_plugin.py | 47 | 47 | 0 | 0%
aipyapp/cli/command/cmd_role.py | 82 | 82 | 0 | 0%
aipyapp/cli/command/cmd_steps.py | 38 | 38 | 0 | 0%
aipyapp/cli/command/cmd_task.py | 134 | 134 | 0 | 0%
aipyapp/cli/command/custom_command_manager.py | 103 | 103 | 0 | 0%
aipyapp/cli/command/manager.py | 308 | 308 | 0 | 0%
aipyapp/cli/command/markdown_command.py | 193 | 193 | 0 | 0%
aipyapp/cli/command/result.py | 16 | 16 | 0 | 0%
aipyapp/cli/command/utils.py | 20 | 20 | 0 | 0%
aipyapp/config/__init__.py | 2 | 2 | 0 | 0%
aipyapp/config/base.py | 18 | 18 | 0 | 0%
aipyapp/config/llm.py | 23 | 23 | 0 | 0%
aipyapp/display/__init__.py | 4 | 4 | 0 | 0%
aipyapp/display/base.py | 69 | 69 | 0 | 0%
aipyapp/display/base_rich.py | 23 | 23 | 0 | 0%
aipyapp/display/manager.py | 62 | 62 | 0 | 0%
aipyapp/display/themes.py | 8 | 8 | 0 | 0%
aipyapp/exec/__init__.py | 3 | 0 | 0 | 100%
aipyapp/exec/executor.py | 65 | 46 | 0 | 29%
aipyapp/exec/html.py | 12 | 7 | 0 | 42%
aipyapp/exec/prun.py | 45 | 22 | 0 | 51%
aipyapp/exec/python/__init__.py | 3 | 0 | 0 | 100%
aipyapp/exec/python/executor.py | 85 | 67 | 0 | 21%
aipyapp/exec/python/mod_dict.py | 64 | 46 | 0 | 28%
aipyapp/exec/python/mod_obj.py | 55 | 38 | 0 | 31%
aipyapp/exec/python/runtime.py | 66 | 43 | 0 | 35%
aipyapp/gui/__init__.py | 7 | 7 | 0 | 0%
aipyapp/gui/about.py | 40 | 40 | 0 | 0%
aipyapp/gui/apimarket.py | 374 | 374 | 0 | 0%
aipyapp/gui/config.py | 120 | 120 | 0 | 0%
aipyapp/gui/main.py | 441 | 441 | 0 | 0%
aipyapp/gui/providers.py | 475 | 475 | 0 | 0%
aipyapp/gui/statusbar.py | 58 | 58 | 0 | 0%
aipyapp/gui/trustoken.py | 134 | 134 | 0 | 0%
aipyapp/i18n.py | 74 | 26 | 0 | 65%
aipyapp/interface.py | 75 | 35 | 3 | 53%
aipyapp/llm/__init__.py | 46 | 6 | 0 | 87%
aipyapp/llm/base.py | 86 | 46 | 0 | 47%
aipyapp/llm/base_openai.py | 51 | 36 | 0 | 29%
aipyapp/llm/client_claude.py | 44 | 31 | 0 | 30%
aipyapp/llm/client_oauth2.py | 34 | 24 | 0 | 29%
aipyapp/llm/client_ollama.py | 33 | 23 | 0 | 30%
aipyapp/llm/models.py | 87 | 46 | 0 | 47%
aipyapp/plugin.py | 49 | 12 | 0 | 76%
aipyapp/plugins/__init__.py | 0 | 0 | 0 | 100%
aipyapp/plugins/live_display.py | 30 | 30 | 0 | 0%
aipyapp/plugins/p_image_tool.py | 47 | 47 | 0 | 0%
aipyapp/plugins/p_style_agent.py | 80 | 80 | 0 | 0%
aipyapp/plugins/p_style_classic.py | 285 | 285 | 0 | 0%
aipyapp/plugins/p_style_minimal.py | 251 | 251 | 0 | 0%
aipyapp/plugins/p_style_modern.py | 363 | 363 | 0 | 0%
aipyapp/plugins/p_style_null.py | 7 | 7 | 0 | 0%
aipyapp/plugins/p_web_tools.py | 72 | 72 | 0 | 0%
aipyapp/runtime.py | 16 | 16 | 0 | 0%
Total | 9388 | 8212 | 9 | 13%

No items found using the specified filter.